#!/usr/bin/env python
# -*- coding: utf-8 -*-

# (canevas repris de Pascal Denis)

import xml.etree.cElementTree as ET
from utils import *

class WSDExample:
    """ Un exemple d'occurrence annotée avec sens, jeu de données=TWA Sense Tagged Data""" 
    def __init__(self, xml_element):
        self._id = xml_element.get('id')
        self._sense = xml_element.find('.//answer').get('senseid')
        if self._sense == "ank%container": # bug in corpus
            self._sense = "tank%container" 
        context_elt = xml_element.find('.//context')
        # l'occurrence désambiguisée est entourée de la balise head
        head_elt = context_elt.find('.//head')
        self._lemma = head_elt.text        
        # le contexte : liste de mots
        self._left_context = normalize_and_split(context_elt.text)
        self._right_context = normalize_and_split(head_elt.tail)
        self._context = self._right_context + self._left_context

    def lemma(self):
        return self._lemma

    def sense(self):
        return self._sense

    def left_context(self):
        return self._left_context

    def right_context(self):
        return self._right_context

    def context(self):
        return self._context


class WSDExamples:
    """ liste d'examples, lues dans un fichier """
    def __init__(self, filepath):
        self.examples = []
        self.parse(filepath)
        return


    def parse(self, filepath):
        # lecture du fichier d'examples,
        # et creation d'une chaine xml valide
        xml_file = open(filepath, 'r')
        xml_str = "%s\n%s\n%s" %('<toto>', xml_file.read(), '</toto>')
        xml_str = xml_str.replace('&',"&amp;")
        xml_file.close()
        # parse effectif du xml
        xml_tree = ET.fromstring(xml_str)
        inst_elts = xml_tree.findall('.//instance')
        for elt in inst_elts:
            example = WSDExample( elt )
            self.examples.append( example ) 
        return



if __name__ == '__main__':
    import sys
    f = sys.argv[1]
    sense_tagged_data = WSDExamples(f)
    for example in sense_tagged_data.examples:
        print example._id, ":", example.lemma(), example.context()

    
    
